# REFERENCE: email_default.xml
__( q{Summary} );
# REFERENCE: email_default.xml
__( q{By Period} );
# REFERENCE: email_default.xml
__( q{Domains} );
# REFERENCE: email_default.xml
__( q{Relays} );
# REFERENCE: email_default.xml
__( q{Delays and Sizes} );
# REFERENCE: email_default.xml
__( q{Hourly} );
# REFERENCE: email_default.xml
__( q{Different Users and Domains} );
# REFERENCE: email_default.xml
__( q{Errors} );
# REFERENCE: schema:email
__( q{DLF Schema for Email service} );
# REFERENCE: schema:email
__( q{The <type>email</type> DLF schema represents delivery done by an mail transfer agent between one <emphasis>one</emphasis> recipient. Each DLF record contains the information related to the process of delivering between one sender and one recipient. Each exchange between one sender and one recipient will results in <emphasis>one and only one</emphasis> DLF record. If one sender is sending to multiple recipients, the DLF file should contains one record for each recipient. </para>  <warning> <para>This DLF schema is different from the other ones because it contains pre-analysed data. It is currently in redesign and will become something that will more closely resemble what you can usually find in an email log file. Different information for each phase of the mail delivery process.</para> <para>That schema will probably become a derived schema from the new base schema. </para> </warning> } );
# REFERENCE: schema:email
__( q{Timestamp} );
# REFERENCE: schema:email
__( q{The time of the first event regarding that delivery. That should be the time the email enter the delivery process. } );
# REFERENCE: schema:email
__( q{Server} );
# REFERENCE: schema:email
__( q{The hostname on which the MTA is running.</para> <warning> <para>That original intent of that field was to analyse email servers' farm which used syslog to centralize their logs. This method of analysis for multiple servers was never actually used and is considerd obsolete. </para> </warning> } );
# REFERENCE: schema:email
__( q{Queue ID} );
# REFERENCE: schema:email
__( q{The queue identifier. This should be the identifier that can be used to reconstitute the delivery process from the native log file regarding the delivery that this DLF record represents. } );
# REFERENCE: schema:email
__( q{Message ID} );
# REFERENCE: schema:email
__( q{The content of the <type>Message-ID</type> header of the delivered message. } );
# REFERENCE: schema:email
__( q{Sender's User} );
# REFERENCE: schema:email
__( q{The local part of the sender's email address.} );
# REFERENCE: schema:email
__( q{Sender's Domain} );
# REFERENCE: schema:email
__( q{The hostname of the sender's email address.} );
# REFERENCE: schema:email
__( q{Sending Relay} );
# REFERENCE: schema:email
__( q{The hostname from which the email was received. For email submitted via the <command>sendmail</command> interface or other similar mechanism, this should be <literal>localhost</literal>. } );
# REFERENCE: schema:email
__( q{from_relay_ip} );
# REFERENCE: schema:email
__( q{The ip address from which the email was received. For email submitted via the <command>sendmail</command> interface or other similar mechanism, this should be <literal>127.0.0.1</literal>. } );
# REFERENCE: schema:email
__( q{Size} );
# REFERENCE: schema:email
__( q{The size of the message.} );
# REFERENCE: schema:email
__( q{Delivery Time} );
# REFERENCE: schema:email
__( q{The time that it took to deliver the message. This should be equivalent to the time of the delivery event minus the value of the <structfield>time</structfield> field. } );
# REFERENCE: schema:email
__( q{Delivery Time} );
# REFERENCE: schema:email
__( q{ <warning> <para>This field was never actually used and is obsolete.</para> </warning> } );
# REFERENCE: schema:email
__( q{Recipient's User} );
# REFERENCE: schema:email
__( q{The local part of the recipient's email address.} );
# REFERENCE: schema:email
__( q{Recipient's Domain} );
# REFERENCE: schema:email
__( q{The hostname of the recipient's email address.} );
# REFERENCE: schema:email
__( q{Receiving Relay} );
# REFERENCE: schema:email
__( q{The hostname to which the email was delivered. If the recipient is a local user and this was the "final" delivery, this should be <literal>localhost</literal>. } );
# REFERENCE: schema:email
__( q{Receiving Relay IP} );
# REFERENCE: schema:email
__( q{The ip address to which the email was delivered. If the recipient is a local user and this was the "final" delivery, this should be <literal>127.0.0.1</literal>. } );
# REFERENCE: schema:email
__( q{Status} );
# REFERENCE: schema:email
__( q{The status code of the delivery. Only standardized code are <literal>sent</literal> which is used when the delivery succeeded without error and <literal>deferred</literal> for when the email still wasn't delivered at the end of the log file. Other values are specific to each service. } );
# REFERENCE: schema:email
__( q{xstat} );
# REFERENCE: schema:email
__( q{The complete native status message related to the email's delivery. } );
# REFERENCE: report:email:deliveries-by-delay
__( q{Deliveries Attempts By Delay Email Report} );
# REFERENCE: report:email:deliveries-by-delay
__( q{This report shows the number of deliveries attempts aggregated in configurable delay range. } );
# REFERENCE: report:email:deliveries-by-delay
__( q{This parameter controls the size of the delay ranges over which the deliveries are aggregated. } );
# REFERENCE: report:email:deliveries-by-delay
__( q{Deliveries Attempts By Delay} );
# REFERENCE: report:email:deliveries-by-delay
__( q{Delay} );
# REFERENCE: report:email:deliveries-by-delay
__( q{Deliveries} );
# REFERENCE: report:email:deliveries-by-delay
__( q{% Total} );
# REFERENCE: report:email:deliveries-by-period-by-status
__( q{Deliveries Attempts By Period By Status Email Report} );
# REFERENCE: report:email:deliveries-by-period-by-status
__( q{This report shows the number of delivery attempts that resulted in a specific status, aggregated in configurable time periods. } );
# REFERENCE: report:email:deliveries-by-period-by-status
__( q{This parameter controls the time period over which the deliveries are aggregated. } );
# REFERENCE: report:email:deliveries-by-period-by-status
__( q{Deliveries Attempts By $period Period By Status} );
# REFERENCE: report:email:deliveries-by-period-by-status
__( q{Period} );
# REFERENCE: report:email:deliveries-by-period-by-status
__( q{Deliveries} );
# REFERENCE: report:email:deliveries-by-period-by-status
__( q{% Total} );
# REFERENCE: report:email:deliveries-by-period-by-status
__( q{% Period} );
# REFERENCE: report:email:deliveries-by-period
__( q{Deliveries Attempts By Period Email Report} );
# REFERENCE: report:email:deliveries-by-period
__( q{This report shows the number of delivery attempts aggregated in configurable time periods. } );
# REFERENCE: report:email:deliveries-by-period
__( q{This parameter controls the time period over which the deliveries are aggregated. } );
# REFERENCE: report:email:deliveries-by-period
__( q{Deliveries Attempts By $period Period} );
# REFERENCE: report:email:deliveries-by-period
__( q{Period} );
# REFERENCE: report:email:deliveries-by-period
__( q{Deliveries} );
# REFERENCE: report:email:deliveries-by-period
__( q{% Total} );
# REFERENCE: report:email:deliveries-by-size
__( q{Deliveries Attempts By Size Email Report} );
# REFERENCE: report:email:deliveries-by-size
__( q{This report shows the number of deliveries attempts aggregated in configurable size range. } );
# REFERENCE: report:email:deliveries-by-size
__( q{This parameter controls the size of the size ranges over which the deliveries are aggregated. } );
# REFERENCE: report:email:deliveries-by-size
__( q{Deliveries Attempts By Size} );
# REFERENCE: report:email:deliveries-by-size
__( q{Size} );
# REFERENCE: report:email:deliveries-by-size
__( q{Deliveries} );
# REFERENCE: report:email:deliveries-by-size
__( q{% Deliveries} );
# REFERENCE: report:email:deliveries-by-size
__( q{Volume} );
# REFERENCE: report:email:deliveries-by-size
__( q{% Volume} );
# REFERENCE: report:email:errors-by-to-relay
__( q{Failed Deliveries By Relay Email Report} );
# REFERENCE: report:email:errors-by-to-relay
__( q{This report shows the errors that happened for each relay that was contacted. } );
# REFERENCE: report:email:errors-by-to-relay
__( q{Failed Deliveries By Relay} );
# REFERENCE: report:email:errors-by-to-relay
__( q{ Note: Only printed is the first word of the stat= field. Therefore: <variablelist>  <varlistentry> <term>service</term> <listitem><para>means service unavailable</para> </listitem> </varlistentry>  <varlistentry> <term>user</term> <listitem><para>means user unknown</para> </listitem> </varlistentry>  <varlistentry> <term>host</term> <listitem><para>means host unknown</para> </listitem> </varlistentry>  <varlistentry> <term>data</term> <listitem><para>means data format error</para> </listitem> </varlistentry>  <varlistentry> <term>remote</term> <listitem><para>means remote protocol error</para> </listitem> </varlistentry>  <varlistentry> <term>can't</term> <listitem><para>means can't create output</para> </listitem> </varlistentry> </variablelist> } );
# REFERENCE: report:email:errors-by-to-relay
__( q{Deliveries} );
# REFERENCE: report:email:errors-by-to-relay
__( q{% Total} );
# REFERENCE: report:email:errors-by-to-relay
__( q{% Group} );
# REFERENCE: report:email:from_domain-by-period
__( q{Different From Domain by Period Email Report} );
# REFERENCE: report:email:from_domain-by-period
__( q{This report shows the number of different email domains that used your email server in an given period. } );
# REFERENCE: report:email:from_domain-by-period
__( q{This parameter controls the time period which will be used to compute different domains. For example, if you use <literal>1d</literal> here, you'll get the number of different source email addresses' domain that sended email through your server in one day. } );
# REFERENCE: report:email:from_domain-by-period
__( q{Different From Domain by $period Period} );
# REFERENCE: report:email:from_domain-by-period
__( q{Period} );
# REFERENCE: report:email:from_domain-by-period
__( q{Domains} );
# REFERENCE: report:email:from_user-from-domain-by-period
__( q{Different From Email for Selected Domains by Period Email Report} );
# REFERENCE: report:email:from_user-from-domain-by-period
__( q{This report shows the number of different local parts from some domains that sended at least an email through the mail system in a given period. } );
# REFERENCE: report:email:from_user-from-domain-by-period
__( q{This parameter controls the time period which will be used to compute different user. For example, if you use <literal>1d</literal> here, you'll get the number of different email addresses' from the selected domains that sended email through your server in one day. } );
# REFERENCE: report:email:from_user-from-domain-by-period
__( q{This parameter contains a regexp that will be used to select the domains for which different from addresses will be computed. } );
# REFERENCE: report:email:from_user-from-domain-by-period
__( q{Different From Users from Domain matching "$select_domain" by $period Period} );
# REFERENCE: report:email:from_user-from-domain-by-period
__( q{Period} );
# REFERENCE: report:email:from_user-from-domain-by-period
__( q{Users} );
# REFERENCE: report:email:summary
__( q{Email Summary} );
# REFERENCE: report:email:summary
__( q{This report shows a summary of email deliveries.} );
# REFERENCE: report:email:summary
__( q{Email Summary} );
# REFERENCE: report:email:summary
__( q{Deliveries} );
# REFERENCE: report:email:summary
__( q{% Total} );
# REFERENCE: report:email:to_domain-by-period
__( q{Different To Domain by Period Email Report} );
# REFERENCE: report:email:to_domain-by-period
__( q{This report shows the number of different email domains to which the server sent an email in an given period. } );
# REFERENCE: report:email:to_domain-by-period
__( q{This parameter controls the time period which will be used to compute different domains. For example, if you use <literal>1d</literal> here, you'll get the number of different destination email addresses' domain that received an email through your server in one day. } );
# REFERENCE: report:email:to_domain-by-period
__( q{Different To Domain by $period Period} );
# REFERENCE: report:email:to_domain-by-period
__( q{Period} );
# REFERENCE: report:email:to_domain-by-period
__( q{Domains} );
# REFERENCE: report:email:to_user-from-domain-by-period
__( q{Different To Email for Selected Domains by Period Email Report} );
# REFERENCE: report:email:to_user-from-domain-by-period
__( q{This report shows the number of different local parts from some domains that received at least an email through the mail system in a given period. } );
# REFERENCE: report:email:to_user-from-domain-by-period
__( q{This parameter controls the time period which will be used to compute different user. For example, if you use <literal>1d</literal> here, you'll get the number of different email addresses' from the selected domains that received an email through your server in one day. } );
# REFERENCE: report:email:to_user-from-domain-by-period
__( q{This parameter contains a regexp that will be used to select the domains for which different to addresses will be computed. } );
# REFERENCE: report:email:to_user-from-domain-by-period
__( q{Different To Users for Domain matching "$select_domain" by $period Period} );
# REFERENCE: report:email:to_user-from-domain-by-period
__( q{Period} );
# REFERENCE: report:email:to_user-from-domain-by-period
__( q{Users} );
# REFERENCE: report:email:top-avg-delay-by-to-relay-and-to-domain
__( q{Highest Average Delay By To Relay And To Domain Email Report} );
# REFERENCE: report:email:top-avg-delay-by-to-relay-and-to-domain
__( q{This report shows the relay and domain with the highest average delay. } );
# REFERENCE: report:email:top-avg-delay-by-to-relay-and-to-domain
__( q{This parameter controls the number of delay to display in the report. } );
# REFERENCE: report:email:top-avg-delay-by-to-relay-and-to-domain
__( q{Highest Average Delay By To Relay and To Domain, Top $delay_to_show} );
# REFERENCE: report:email:top-avg-delay-by-to-relay-and-to-domain
__( q{Average delay is in seconds} );
# REFERENCE: report:email:top-avg-delay-by-to-relay-and-to-domain
__( q{Avg Delay} );
# REFERENCE: report:email:top-deliveries-btw-relays
__( q{Most Deliveries Between Relays Email Report} );
# REFERENCE: report:email:top-deliveries-btw-relays
__( q{This report lists the connections between two relays with the most deliveries.} );
# REFERENCE: report:email:top-deliveries-btw-relays
__( q{This parameter controls the number of connections to display in the report. } );
# REFERENCE: report:email:top-deliveries-btw-relays
__( q{Most Deliveries Between Relays, Top $connection_to_show} );
# REFERENCE: report:email:top-deliveries-btw-relays
__( q{Deliveries} );
# REFERENCE: report:email:top-deliveries-btw-relays
__( q{% Total} );
# REFERENCE: report:email:top-from-domain
__( q{Most Deliveries From Domain Email Report} );
# REFERENCE: report:email:top-from-domain
__( q{This report lists the domain from which we received the most emails.} );
# REFERENCE: report:email:top-from-domain
__( q{This parameter controls the number of domains to display in the report. } );
# REFERENCE: report:email:top-from-domain
__( q{Most Deliveries From Domain, Top $domain_to_show} );
# REFERENCE: report:email:top-from-domain
__( q{Deliveries} );
# REFERENCE: report:email:top-from-domain
__( q{% Total} );
# REFERENCE: report:email:top-from-email-by-domain
__( q{Most Deliveries From User By Domain Email Report} );
# REFERENCE: report:email:top-from-email-by-domain
__( q{This report lists the user by domain from which we received the most emails. } );
# REFERENCE: report:email:top-from-email-by-domain
__( q{This parameter controls the number of user by domain to display in the report. } );
# REFERENCE: report:email:top-from-email-by-domain
__( q{This parameter controls the number of domains to display in the report. } );
# REFERENCE: report:email:top-from-email-by-domain
__( q{Most Deliveries From User By Domain, Top $domain_to_show, Top $user_to_show Users} );
# REFERENCE: report:email:top-from-email-by-domain
__( q{Deliveries} );
# REFERENCE: report:email:top-from-email-by-domain
__( q{% Total} );
# REFERENCE: report:email:top-from-email-by-domain
__( q{% Group} );
# REFERENCE: report:email:top-from-relay
__( q{Most Deliveries From Relay Email Report} );
# REFERENCE: report:email:top-from-relay
__( q{This report lists the relay from which we received the most emails. } );
# REFERENCE: report:email:top-from-relay
__( q{This parameter controls the number of relays to display in the report. } );
# REFERENCE: report:email:top-from-relay
__( q{Most Deliveries From Relay, Top $relay_to_show} );
# REFERENCE: report:email:top-from-relay
__( q{Deliveries} );
# REFERENCE: report:email:top-from-relay
__( q{% Total} );
# REFERENCE: report:email:top-largest-email-exchange-per-relay
__( q{Largest Email Exchange Per Relay Pair Email Report} );
# REFERENCE: report:email:top-largest-email-exchange-per-relay
__( q{This report lists the pairs of from- and to-relays which exchanged the largest volume of email. } );
# REFERENCE: report:email:top-largest-email-exchange-per-relay
__( q{This parameter controls the number of to-relays per from-relay to display in the report. } );
# REFERENCE: report:email:top-largest-email-exchange-per-relay
__( q{This parameter controls the number of from-relays to display in the report. } );
# REFERENCE: report:email:top-largest-email-exchange-per-relay
__( q{Largest Email Exchange by Relay Pair, Top $exchange_to_show From-relays, Top $msg_to_show To-relays} );
# REFERENCE: report:email:top-largest-email-exchange-per-relay
__( q{Volume} );
# REFERENCE: report:email:top-largest-email-exchange-per-relay
__( q{% Total} );
# REFERENCE: report:email:top-largest-email-exchange-per-relay
__( q{% Group} );
# REFERENCE: report:email:top-largest-email-exchange
__( q{Largest Email Exchange Email Report} );
# REFERENCE: report:email:top-largest-email-exchange
__( q{This report the sender and recipient that exchange the largest volume of email. } );
# REFERENCE: report:email:top-largest-email-exchange
__( q{This parameter controls the number of messages to display in the report. } );
# REFERENCE: report:email:top-largest-email-exchange
__( q{This parameter controls the number of sender, recipient to display in the report. } );
# REFERENCE: report:email:top-largest-email-exchange
__( q{Largest Email Exchange, Top $exchange_to_show, Top $msg_to_show Messages} );
# REFERENCE: report:email:top-largest-email-exchange
__( q{Volume} );
# REFERENCE: report:email:top-largest-email-exchange
__( q{% Total} );
# REFERENCE: report:email:top-status-by-domain
__( q{Status Summary For Most Common Domains} );
# REFERENCE: report:email:top-status-by-domain
__( q{This report is a summary for the most common domains.} );
# REFERENCE: report:email:top-status-by-domain
__( q{This parameter controls the number of domains to display in the report.} );
# REFERENCE: report:email:top-status-by-domain
__( q{Summary of delivery for the most common domains.} );
# REFERENCE: report:email:top-status-by-domain
__( q{Deliveries} );
# REFERENCE: report:email:top-status-by-domain
__( q{% Total} );
# REFERENCE: report:email:top-status-by-domain
__( q{% Domain} );
# REFERENCE: report:email:top-to-domain
__( q{Most Deliveries To Domain Email Report} );
# REFERENCE: report:email:top-to-domain
__( q{This report lists the domain to which we sent the most emails.} );
# REFERENCE: report:email:top-to-domain
__( q{This parameter controls the number of domains to display in the report. } );
# REFERENCE: report:email:top-to-domain
__( q{Most Deliveries To Domain, Top $domain_to_show} );
# REFERENCE: report:email:top-to-domain
__( q{Deliveries} );
# REFERENCE: report:email:top-to-domain
__( q{% Total} );
# REFERENCE: report:email:top-to-email-by-domain
__( q{Most Deliveries To User By Domain Email Report} );
# REFERENCE: report:email:top-to-email-by-domain
__( q{This report lists the user by domain to which we sent the most emails.} );
# REFERENCE: report:email:top-to-email-by-domain
__( q{This parameter controls the number of user by domain to display in the report. } );
# REFERENCE: report:email:top-to-email-by-domain
__( q{This parameter controls the number of domains to display in the report. } );
# REFERENCE: report:email:top-to-email-by-domain
__( q{Most Deliveries To User By Domain, Top $domain_to_show, Top $user_to_show Users} );
# REFERENCE: report:email:top-to-email-by-domain
__( q{Deliveries} );
# REFERENCE: report:email:top-to-email-by-domain
__( q{% Total} );
# REFERENCE: report:email:top-to-email-by-domain
__( q{% Domain} );
# REFERENCE: report:email:top-to-relay
__( q{Most Deliveries From Relay Email Report} );
# REFERENCE: report:email:top-to-relay
__( q{This report lists the relay to which we sent the most emails. } );
# REFERENCE: report:email:top-to-relay
__( q{This parameter controls the number of relays to display in the report. } );
# REFERENCE: report:email:top-to-relay
__( q{Most Deliveries To Relay, Top $relay_to_show} );
# REFERENCE: report:email:top-to-relay
__( q{Deliveries} );
# REFERENCE: report:email:top-to-relay
__( q{% Total} );
# REFERENCE: report:email:top-volume-from-domain
__( q{Largest Volume Received From Domain Email Report} );
# REFERENCE: report:email:top-volume-from-domain
__( q{This report lists the domain from which we received the largest volume of mail.} );
# REFERENCE: report:email:top-volume-from-domain
__( q{This parameter controls the number of domains to display in the report. } );
# REFERENCE: report:email:top-volume-from-domain
__( q{Largest Volume Received From Domain, Top $domain_to_show} );
# REFERENCE: report:email:top-volume-from-domain
__( q{Volume} );
# REFERENCE: report:email:top-volume-from-domain
__( q{% Total} );
# REFERENCE: report:email:top-volume-to-domain
__( q{Largest Volume Sent To Domain Email Report} );
# REFERENCE: report:email:top-volume-to-domain
__( q{This report lists the domains to which the largest volume of mail was sent.} );
# REFERENCE: report:email:top-volume-to-domain
__( q{This parameter controls the number of domains to display in the report. } );
# REFERENCE: report:email:top-volume-to-domain
__( q{Largest Volume Sent To Domain, Top $domain_to_show} );
# REFERENCE: report:email:top-volume-to-domain
__( q{Volume} );
# REFERENCE: report:email:top-volume-to-domain
__( q{% Total} );
# REFERENCE: report:email:tracked-recipients
__( q{Tracked Recipients Email Report} );
# REFERENCE: report:email:tracked-recipients
__( q{This report shows the number of messages received from each sender for selected recipient emails. } );
# REFERENCE: report:email:tracked-recipients
__( q{This parameter controls which recipient emails will be included in the report.  E.g. "joe\\@example\\.com" or "(joe|ann|mailer-daemon)\\@example\\.org" or "root\\@example\\.com|john\\.doe\\@example\\.net": regexp's should be Perl style, with suitable escaping. } );
# REFERENCE: report:email:tracked-recipients
__( q{Senders By Recipients Matching $tracked_email_re} );
# REFERENCE: report:email:tracked-recipients
__( q{Received} );
# REFERENCE: report:email:tracked-recipients
__( q{% Total} );
# REFERENCE: report:email:tracked-senders
__( q{Tracked Senders Email Report} );
# REFERENCE: report:email:tracked-senders
__( q{This report shows the number of messages sent to each recipients for selected sender emails. } );
# REFERENCE: report:email:tracked-senders
__( q{This parameter controls which sender emails will be included in the report.  E.g. "joe\\@example\\.com" or "(joe|ann|mailer-daemon)\\@example\\.org" or "root\\@example\\.com|john\\.doe\\@example\\.net": regexp's should be Perl style, with suitable escaping. } );
# REFERENCE: report:email:tracked-senders
__( q{Recipients By Senders Matching $tracked_email_re} );
# REFERENCE: report:email:tracked-senders
__( q{Sent} );
# REFERENCE: report:email:tracked-senders
__( q{% Total} );
# REFERENCE: report:email:volume-by-period
__( q{Volume Delivered By Period Email Report} );
# REFERENCE: report:email:volume-by-period
__( q{ This report shows the volume of delivered emails in configurable time period. } );
# REFERENCE: report:email:volume-by-period
__( q{This parameter controls the time period over which the deliveries are aggregated. } );
# REFERENCE: report:email:volume-by-period
__( q{Volume Delivered By $period Period} );
# REFERENCE: report:email:volume-by-period
__( q{<note> <para> One email delivered to multiple destinations will be accounted for multiple times. For example, one 1K email sent to two recipients will count for 2K of volume. </para> </note> } );
# REFERENCE: report:email:volume-by-period
__( q{Period} );
# REFERENCE: report:email:volume-by-period
__( q{Volume} );
# REFERENCE: report:email:volume-by-period
__( q{% Total} );
# REFERENCE: filter:email:select-client-ip
__( q{Select Client IP Filter} );
# REFERENCE: filter:email:select-client-ip
__( q{This filter specification can be used to select the deliveries coming from a particular client host or relay. } );
# REFERENCE: filter:email:select-client-ip
__( q{This parameter contains the regular expression that will be used to select the deliveries coming from particular hosts. Only deliveries made by a client host matching that regexp will be included in the subreports. The match is done on the client IP address (not its hostname). } );
# REFERENCE: filter:email:select-client-ip
__( q{selected deliveries coming from IP addresses matching $ip-range ip} );
